==> caret_5.6.1~dfsg.1.orig.tar.gz: caret-5.6.1/caret_command_operations/CommandSurfaceBorderVariability.h <==

#ifndef __COMMAND_SURFACE_BORDER_VARIABILITY_H__
#define __COMMAND_SURFACE_BORDER_VARIABILITY_H__

/*LICENSE_START*/
/*
 *  Copyright 1995-2002 Washington University School of Medicine
 *
 *  http://brainmap.wustl.edu
 *
 *  This file is part of CARET.
 *
 *  CARET is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  CARET is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with CARET; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
/*LICENSE_END*/

#include "CommandBase.h"

class BorderFile;

/// class for surface border variability
class CommandSurfaceBorderVariability : public CommandBase {
   public:
      // constructor 
      CommandSurfaceBorderVariability();
      
      // destructor
      ~CommandSurfaceBorderVariability();
      
      // get full help information
      QString getHelpInformation() const;
      
      // get the script builder parameters
      virtual void getScriptBuilderParameters(ScriptBuilderParameters& paramsOut) const;
      
   protected:
      // execute the command
      void executeCommand() throw (BrainModelAlgorithmException,
                                   CommandException,
                                   FileException,
                                   ProgramParametersException,
                                   StatisticException);

      /// do the border report
      void doBorderReport(const BorderFile& bf);

      /// do the border point report
      void doBorderPointReport(const BorderFile& bf,
                               const BorderFile& avgBorderFile)
                                                throw (CommandException);
};

#endif // __COMMAND_SURFACE_BORDER_VARIABILITY_H__

==> caret_5.6.4~dfsg.1.orig.tar.gz: caret-5.6.4~dfsg.1.orig/caret_command_operations/CommandSurfaceBorderVariability.h <==

#ifndef __COMMAND_SURFACE_BORDER_VARIABILITY_H__
#define __COMMAND_SURFACE_BORDER_VARIABILITY_H__

/*LICENSE_START*/
/*
 *  Copyright 1995-2002 Washington University School of Medicine
 *
 *  http://brainmap.wustl.edu
 *
 *  This file is part of CARET.
 *
 *  CARET is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  CARET is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with CARET; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
/*LICENSE_END*/

#include "CommandBase.h"

class BorderFile;

/// class for surface border variability
class CommandSurfaceBorderVariability : public CommandBase {
   public:
      // constructor 
      CommandSurfaceBorderVariability();
      
      // destructor
      ~CommandSurfaceBorderVariability();
      
      // get full help information
      QString getHelpInformation() const;
      
      // get the script builder parameters
      virtual void getScriptBuilderParameters(ScriptBuilderParameters& paramsOut) const;
      
   protected:
      // execute the command
      void executeCommand() throw (BrainModelAlgorithmException,
                                   CommandException,
                                   FileException,
                                   ProgramParametersException,
                                   StatisticException);

      /// do the border report
      void doBorderReport(const BorderFile& bf,
                          const float threshold,
                          const bool showRatiosExceededFlag);

      /// do the border point report
      void doBorderPointReport(const BorderFile& bf,
                               const BorderFile& avgBorderFile,
                               const float threshold)
                                                throw (CommandException);
};

#endif // __COMMAND_SURFACE_BORDER_VARIABILITY_H__
